==> moodle_1.3.1.orig.tar.gz: moodle/lang/de_du/workshop.php <==
<?PHP // $Id: workshop.php,v 1.1 2003/06/12 03:32:05 moodler Exp $ 
      // workshop.php - created with Moodle 1.0.9 Beta 1 (2003051600)


$string['accumulative'] = "Wachsend";
$string['action'] = "Aktion";
$string['addacomment'] = "Einen Kommentar hinzufgen";
$string['afterdeadline'] = "Nach dem Stichtag: \$a";
$string['agreetothisassessment'] = "Dieser Bewertungzustimmen";
$string['allgradeshaveamaximumof'] = "Alle Noten haben ein Maximum von: \$a";
$string['allowresubmit'] = "Wiedereintrge erlauben";
$string['alreadyinphase'] = "Schon in Phase \$a";
$string['amendassessmentelements'] = "Bewertungskriterien ndern";
$string['assess'] = "Bewerte";
$string['assessedon'] = "Bewertet von \$a";
$string['assessment'] = "Bewertung";
$string['assessmentgrade'] = "Bewertungsnote: \$a";
$string['assessmentnotyetagreed'] = "Bewertung noch nicht zugestimmt";
$string['assessmentofthissubmission'] = "Bewertung dieses Beitrages";
$string['assessments'] = "Bewertungen";
$string['assessmentsareok'] = "Bewertungen sind OK";
$string['assessmentsby'] = "Bewertungen von \$a";
$string['assessmentsdone'] = "Bewertungen erledigt";
$string['assessmentsmustbeagreed'] = "Bewertungen muss zugestimmt werden";
$string['assessmentwasagreedon'] = "Bewertung wurde zugestimmt von \$a";
$string['assessor'] = "Bewerter";
$string['assessthissubmission'] = "Bewerte diesen Beitrag";
$string['assignmentnotinthecorrectphase'] = "Bewertung nicht in der richtigern Phase";
$string['authorofsubmission'] = "Autor des Beitrages";
$string['awaitinggradingbyteacher'] = "Erwarte Benotung von \$a";
$string['beforedeadline'] = "Vor dem Stichtag: \$a";
$string['calculationoffinalgrades'] = "Berechnung der Endnote";
$string['closeassignment'] = "Aufgabe schliessen";
$string['comment'] = "Kommentar";
$string['commentby'] = "Kommentiert von";
$string['criteria'] = "Kriterien";
$string['deadline'] = "Stichtag";
$string['deadlineis'] = "Der Stichtag ist \$a";
$string['description'] = "Beschreibung";
$string['detailsofassessment'] = "Bewertungsdetails";
$string['disagreewiththisassessment'] = "Dieser Bewertung nicht zustimmen";
$string['displayoffinalgrades'] = "Anzeige der Endnoten";
$string['dontshowgrades'] = "Keine Noten anzeigen";
$string['edit'] = "Bearbeiten";
$string['editacomment'] = "Einen Kommentar bearbeiten";
$string['editingassessmentelements'] = "Bewertungskriterien bearbeiten";
$string['element'] = "Kriterium";
$string['elementweight'] = "Kriteriumswichtung";
$string['errorbanded'] = "Fehlermarkierung";
$string['feedbackgoeshere'] = "Rckmeldung hier";
$string['generalcomment'] = "Allgemeiner Kommentar";
$string['grade'] = "Note";
$string['gradeassessment'] = "Bewertungsnote";
$string['graded'] = "Benotet";
$string['gradedbyteacher'] = "Benotet von \$a";
$string['gradeforassessments'] = "Note fr Bewertung";
$string['gradeforbias'] = "Note fr Vorbereitung";
$string['gradeforreliability'] = "Note fr Zuverlssigkeit";
$string['gradeforstudentsassessment'] = "Note fr Bewertung des Kurteilnehmers";
$string['gradeofsubmission'] = "Note des Beitrages: \$a";
$string['gradingstrategy'] = "Benotungsstrategie";
$string['hidegradesbeforeagreement'] = "Noten vor Zustimmung verbergen";
$string['includeteachersgrade'] = "Note des Lehrers einbeziehen";
$string['listofallsubmissions'] = "Liste aller Beitrge";
$string['managingassignment'] = "Handhabung der Aufgaben";
$string['maximumsize'] = "Maximale Gre";
$string['modulename'] = "Workshop";
$string['modulenameplural'] = "Workshops";
$string['movedtophase'] = "Verschoben in Phase \$a";
$string['moveonto'] = "Weiterverschieben nach";
$string['noassessmentsdone'] = "Keine Bewertung durchgefhrt";
$string['nosubmissionsavailableforassessment'] = "Keine Beitrge fr die Bewertung vorhanden";
$string['notavailable'] = "Nicht verfgbar";
$string['noteonassessmentelements'] = "Beachte, dass die Benotung aufgeteilt ist in eine Anzahl von 'Bewertungskriterien'.<br>
Dies macht die Benotung einfacher und plausibeler. Als Kursleiter musst Du diese<br>
Kriterien hinzufgen, bevor Du die Aufgabe dem Kursteilnehmer zugnglich machst. Dies geschieht durch das <br>Klicken auf die Aufgabe im Kurs. Wenn keine Kriterien vorhanden sind, wirst Du gebeten<br>diese hinzuzufgen. Du kannst die Anzahl der Kriterien ndern, indem Du die Seite der Aufgabenbearbeitung benutzt,<br>
die Kriterien selbst knnen ber die Seite &quot;Aufgabenverwaltung&quot; bearbeitet werden";
$string['notgraded'] = "Nicht benotet";
$string['notitlegiven'] = "Kein Titel angegeben";
$string['numberofassessmentelements'] = "Anzahl der Kommentare, Bewertungskriterien, Note des Verbunds oder Kriteriumsaussage";
$string['numberofassessments'] = "Anzahl der Bewertungen";
$string['numberofassessmentsofstudentsubmissions'] = "Anzahl Bewertungen der Kursteilnehmer-Beitrge";
$string['numberofassessmentsofteachersexamples'] = "Anzahl der Bewertungen von Beispielen vom Kursleiter";
$string['on'] = "von \$a";
$string['openassignment'] = "Aufgabe ffnen";
$string['optionforpeergrade'] = "Auswahl frDurchschnittsnote";
$string['overallgrade'] = "Gesamtnote";
$string['overallpeergrade'] = "Gesamtdurchschnittsnote: \$a";
$string['overallteachergrade'] = "Gesamtnote des Lehrers: \$a";
$string['ownwork'] = "Eigene Arbeit";
$string['phase'] = "Phase";
$string['phase1'] = "Aufgabe erzeugen";
$string['phase2'] = "\$a Beitrge und Aufgaben";
$string['phase3'] = "Berechnung der Gesamtnote";
$string['phase4'] = "Gesamtnoten anzeigen";
$string['pleaseassesstheseexamplesfromtheteacher'] = "Bitte bewerte dieses Beispiel von \$a";
$string['pleaseassessthesestudentsubmissions'] = "Bitte bewerte diese \$a Beitrge";
$string['reply'] = "Antworten";
$string['returnto'] = "Zurckkehren zu";
$string['returntosubmissionpage'] = "Zur Beitragsseite zurckkehren";
$string['savedok'] = "Gespeichert OK";
$string['savemyassessment'] = "Meine Bewertung speichern";
$string['savemycomment'] = "Meinen Kommentar speichern";
$string['savemygrading'] = "Meine Benotung speichern";
$string['scale10'] = "Punkte von 10";
$string['scale100'] = "Punkte von 100";
$string['scale20'] = "Punkte von 20";
$string['scalecorrect'] = "2 Punkt Richtig/Falsch-Skala";
$string['scaleexcellent4'] = "4 Punkt Sehr Gut/Ungengend-Skala";
$string['scaleexcellent5'] = "5 Punkt Sehr Gut/Ungengend-Skalae";
$string['scaleexcellent7'] = "7 Punkt Sehr Gut/Ungengend-Skalae";
$string['scalegood3'] = "3 Punkt Gut/Mangelhaft-Skala";
$string['scalepresent'] = "2 Punkt Anwesenheits/Abwesenheitsskala";
$string['scaleyes'] = "2 Punkt Ja/Nein Skala";
$string['selfassessment'] = "Selbsteinschtzung";
$string['showgrades'] = "Noten anzeigen";
$string['specimenassessmentform'] = "Bezeichnung der Bewerungsform";
$string['studentgrades'] = "\$a Noten";
$string['studentsassessment'] = "Bewertung der Kursteilnehmer";
$string['studentsubmissions'] = "\$a Beitrge";
$string['studentsubmissionsforassessment'] = "\$a Beitrge der Studenten zur Bewertung";
$string['submissions'] = "Beitrge";
$string['submitassignment'] = "Aufgabe einreichen";
$string['submitexampleassignment'] = "Beispielufgabe einreichen";
$string['submitted'] = "Eingereicht";
$string['teachersassessment'] = "Aufgabe des Kursleiters";
$string['teacherscomment'] = "Kommentar des Kursleiters";
$string['teachersgrade'] = "Note des Kursleiters";
$string['teachersubmissionsforassessment'] = "\$a Beitrge des Lehrers zur Bewertung";
$string['thegradeis'] = "Die Note ist \$a";
$string['theseasessmentsaregradedbytheteacher'] = "Diese Bewertung wurde benotet durch den \$a";
$string['timeassessed'] = "Angesetzte Zeit";
$string['title'] = "Titel";
$string['typeofscale'] = "Skalentyp";
$string['ungradedassessmentsofstudentsubmissions'] = "\$a unbenotete Bewertungen von Kursteilnehmer-Beitrgen";
$string['ungradedassessmentsofteachersubmissions'] = "\$a unbenotete Bewertungen von Kursleiter-Beitrgen";
$string['view'] = "Ansicht";
$string['viewassessmentofteacher'] = "Bewertung anzeigen von \$a";
$string['viewotherassessments'] = "Andere Bewertungen anzeigen";
$string['warningonamendingelements'] = "WARNUNG: Es existieren eingereichte Bewertungen<br>ndern Sie nicht die Anzahl der Kriterien, den Skalentyp oder die Kriterienwichtung";
$string['weightederrorcount'] = "Durchnittsfehlerzahl: \$a";
$string['weightforbias'] = "Wichtung fr Vorbereitung";
$string['weightforgradingofassessments'] = "Wichtung der Benotung der Bewertungen";
$string['weightforpeerassessments'] = "Wichtung fr Durchschnittsbewertung";
$string['weightforreliability'] = "Wichtung der Zuverlssigkeit";
$string['weightforteachersassessment'] = "Wichtung der Kursleiter-Bewertung";
$string['weights'] = "Wichtungen";
$string['weightsusedforfinalgrade'] = "Wichtungen, die ifr die Endnote verwendet werdem";
$string['weightsusedforsubmissions'] = "Wichtungen, die fr die Beitrge verwenden werden";
$string['yourassessments'] = "Deine Bewertung";

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/de_du/workshop.php <==
<?PHP // $Id$ 
      // workshop.php - created with Moodle 1.0.9 Beta 1 (2003051600)


$string['accumulative'] = "Wachsend";
$string['action'] = "Aktion";
$string['addacomment'] = "Einen Kommentar hinzufgen";
$string['afterdeadline'] = "Nach dem Stichtag: \$a";
$string['agreetothisassessment'] = "Dieser Bewertungzustimmen";
$string['allgradeshaveamaximumof'] = "Alle Noten haben ein Maximum von: \$a";
$string['allowresubmit'] = "Wiedereintrge erlauben";
$string['alreadyinphase'] = "Schon in Phase \$a";
$string['amendassessmentelements'] = "Bewertungskriterien ndern";
$string['assess'] = "Bewerte";
$string['assessedon'] = "Bewertet von \$a";
$string['assessment'] = "Bewertung";
$string['assessmentgrade'] = "Bewertungsnote: \$a";
$string['assessmentnotyetagreed'] = "Bewertung noch nicht zugestimmt";
$string['assessmentofthissubmission'] = "Bewertung dieses Beitrages";
$string['assessments'] = "Bewertungen";
$string['assessmentsareok'] = "Bewertungen sind OK";
$string['assessmentsby'] = "Bewertungen von \$a";
$string['assessmentsdone'] = "Bewertungen erledigt";
$string['assessmentsmustbeagreed'] = "Bewertungen muss zugestimmt werden";
$string['assessmentwasagreedon'] = "Bewertung wurde zugestimmt von \$a";
$string['assessor'] = "Bewerter";
$string['assessthissubmission'] = "Bewerte diesen Beitrag";
$string['assignmentnotinthecorrectphase'] = "Bewertung nicht in der richtigern Phase";
$string['authorofsubmission'] = "Autor des Beitrages";
$string['awaitinggradingbyteacher'] = "Erwarte Benotung von \$a";
$string['beforedeadline'] = "Vor dem Stichtag: \$a";
$string['calculationoffinalgrades'] = "Berechnung der Endnote";
$string['closeassignment'] = "Aufgabe schliessen";
$string['comment'] = "Kommentar";
$string['commentby'] = "Kommentiert von";
$string['criteria'] = "Kriterien";
$string['deadline'] = "Stichtag";
$string['deadlineis'] = "Der Stichtag ist \$a";
$string['description'] = "Beschreibung";
$string['detailsofassessment'] = "Bewertungsdetails";
$string['disagreewiththisassessment'] = "Dieser Bewertung nicht zustimmen";
$string['displayoffinalgrades'] = "Anzeige der Endnoten";
$string['dontshowgrades'] = "Keine Noten anzeigen";
$string['edit'] = "Bearbeiten";
$string['editacomment'] = "Einen Kommentar bearbeiten";
$string['editingassessmentelements'] = "Bewertungskriterien bearbeiten";
$string['element'] = "Kriterium";
$string['elementweight'] = "Kriteriumswichtung";
$string['errorbanded'] = "Fehlermarkierung";
$string['feedbackgoeshere'] = "Rckmeldung hier";
$string['generalcomment'] = "Allgemeiner Kommentar";
$string['grade'] = "Note";
$string['gradeassessment'] = "Bewertungsnote";
$string['graded'] = "Benotet";
$string['gradedbyteacher'] = "Benotet von \$a";
$string['gradeforassessments'] = "Note fr Bewertung";
$string['gradeforbias'] = "Note fr Vorbereitung";
$string['gradeforreliability'] = "Note fr Zuverlssigkeit";
$string['gradeforstudentsassessment'] = "Note fr Bewertung des Kurteilnehmers";
$string['gradeofsubmission'] = "Note des Beitrages: \$a";
$string['gradingstrategy'] = "Benotungsstrategie";
$string['hidegradesbeforeagreement'] = "Noten vor Zustimmung verbergen";
$string['includeteachersgrade'] = "Note des Lehrers einbeziehen";
$string['listofallsubmissions'] = "Liste aller Beitrge";
$string['managingassignment'] = "Handhabung der Aufgaben";
$string['maximumsize'] = "Maximale Gre";
$string['modulename'] = "Workshop";
$string['modulenameplural'] = "Workshops";
$string['movedtophase'] = "Verschoben in Phase \$a";
$string['moveonto'] = "Weiterverschieben nach";
$string['noassessmentsdone'] = "Keine Bewertung durchgefhrt";
$string['nosubmissionsavailableforassessment'] = "Keine Beitrge fr die Bewertung vorhanden";
$string['notavailable'] = "Nicht verfgbar";
$string['noteonassessmentelements'] = "Beachte, dass die Benotung aufgeteilt ist in eine Anzahl von 'Bewertungskriterien'.<br />
Dies macht die Benotung einfacher und plausibeler. Als Kursleiter musst Du diese<br />
Kriterien hinzufgen, bevor Du die Aufgabe dem Kursteilnehmer zugnglich machst. Dies geschieht durch das <br />Klicken auf die Aufgabe im Kurs. Wenn keine Kriterien vorhanden sind, wirst Du gebeten<br />diese hinzuzufgen. Du kannst die Anzahl der Kriterien ndern, indem Du die Seite der Aufgabenbearbeitung benutzt,<br />
die Kriterien selbst knnen ber die Seite &quot;Aufgabenverwaltung&quot; bearbeitet werden";
$string['notgraded'] = "Nicht benotet";
$string['notitlegiven'] = "Kein Titel angegeben";
$string['numberofassessmentelements'] = "Anzahl der Kommentare, Bewertungskriterien, Note des Verbunds oder Kriteriumsaussage";
$string['numberofassessments'] = "Anzahl der Bewertungen";
$string['numberofassessmentsofstudentsubmissions'] = "Anzahl Bewertungen der Kursteilnehmer-Beitrge";
$string['numberofassessmentsofteachersexamples'] = "Anzahl der Bewertungen von Beispielen vom Kursleiter";
$string['on'] = "von \$a";
$string['openassignment'] = "Aufgabe ffnen";
$string['optionforpeergrade'] = "Auswahl frDurchschnittsnote";
$string['overallgrade'] = "Gesamtnote";
$string['overallpeergrade'] = "Gesamtdurchschnittsnote: \$a";
$string['overallteachergrade'] = "Gesamtnote des Lehrers: \$a";
$string['ownwork'] = "Eigene Arbeit";
$string['phase'] = "Phase";
$string['phase1'] = "Aufgabe erzeugen";
$string['phase2'] = "\$a Beitrge und Aufgaben";
$string['phase3'] = "Berechnung der Gesamtnote";
$string['phase4'] = "Gesamtnoten anzeigen";
$string['pleaseassesstheseexamplesfromtheteacher'] = "Bitte bewerte dieses Beispiel von \$a";
$string['pleaseassessthesestudentsubmissions'] = "Bitte bewerte diese \$a Beitrge";
$string['reply'] = "Antworten";
$string['returnto'] = "Zurckkehren zu";
$string['returntosubmissionpage'] = "Zur Beitragsseite zurckkehren";
$string['savedok'] = "Gespeichert OK";
$string['savemyassessment'] = "Meine Bewertung speichern";
$string['savemycomment'] = "Meinen Kommentar speichern";
$string['savemygrading'] = "Meine Benotung speichern";
$string['scale10'] = "Punkte von 10";
$string['scale100'] = "Punkte von 100";
$string['scale20'] = "Punkte von 20";
$string['scalecorrect'] = "2 Punkt Richtig/Falsch-Skala";
$string['scaleexcellent4'] = "4 Punkt Sehr Gut/Ungengend-Skala";
$string['scaleexcellent5'] = "5 Punkt Sehr Gut/Ungengend-Skalae";
$string['scaleexcellent7'] = "7 Punkt Sehr Gut/Ungengend-Skalae";
$string['scalegood3'] = "3 Punkt Gut/Mangelhaft-Skala";
$string['scalepresent'] = "2 Punkt Anwesenheits/Abwesenheitsskala";
$string['scaleyes'] = "2 Punkt Ja/Nein Skala";
$string['selfassessment'] = "Selbsteinschtzung";
$string['showgrades'] = "Noten anzeigen";
$string['specimenassessmentform'] = "Bezeichnung der Bewerungsform";
$string['studentgrades'] = "\$a Noten";
$string['studentsassessment'] = "Bewertung der Kursteilnehmer";
$string['studentsubmissions'] = "\$a Beitrge";
$string['studentsubmissionsforassessment'] = "\$a Beitrge der Studenten zur Bewertung";
$string['submissions'] = "Beitrge";
$string['submitassignment'] = "Aufgabe einreichen";
$string['submitexampleassignment'] = "Beispielufgabe einreichen";
$string['submitted'] = "Eingereicht";
$string['teachersassessment'] = "Aufgabe des Kursleiters";
$string['teacherscomment'] = "Kommentar des Kursleiters";
$string['teachersgrade'] = "Note des Kursleiters";
$string['teachersubmissionsforassessment'] = "\$a Beitrge des Lehrers zur Bewertung";
$string['thegradeis'] = "Die Note ist \$a";
$string['theseasessmentsaregradedbytheteacher'] = "Diese Bewertung wurde benotet durch den \$a";
$string['timeassessed'] = "Angesetzte Zeit";
$string['title'] = "Titel";
$string['typeofscale'] = "Skalentyp";
$string['ungradedassessmentsofstudentsubmissions'] = "\$a unbenotete Bewertungen von Kursteilnehmer-Beitrgen";
$string['ungradedassessmentsofteachersubmissions'] = "\$a unbenotete Bewertungen von Kursleiter-Beitrgen";
$string['view'] = "Ansicht";
$string['viewassessmentofteacher'] = "Bewertung anzeigen von \$a";
$string['viewotherassessments'] = "Andere Bewertungen anzeigen";
$string['warningonamendingelements'] = "WARNUNG: Es existieren eingereichte Bewertungen<br />ndern Sie nicht die Anzahl der Kriterien, den Skalentyp oder die Kriterienwichtung";
$string['weightederrorcount'] = "Durchnittsfehlerzahl: \$a";
$string['weightforbias'] = "Wichtung fr Vorbereitung";
$string['weightforgradingofassessments'] = "Wichtung der Benotung der Bewertungen";
$string['weightforpeerassessments'] = "Wichtung fr Durchschnittsbewertung";
$string['weightforreliability'] = "Wichtung der Zuverlssigkeit";
$string['weightforteachersassessment'] = "Wichtung der Kursleiter-Bewertung";
$string['weights'] = "Wichtungen";
$string['weightsusedforfinalgrade'] = "Wichtungen, die ifr die Endnote verwendet werdem";
$string['weightsusedforsubmissions'] = "Wichtungen, die fr die Beitrge verwenden werden";
$string['yourassessments'] = "Deine Bewertung";

?>
